summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/ant/Scaladoc.scala
diff options
context:
space:
mode:
authormichelou <michelou@epfl.ch>2007-04-24 17:29:05 +0000
committermichelou <michelou@epfl.ch>2007-04-24 17:29:05 +0000
commit2647716232805f77ed81eabc491759f5362d5e01 (patch)
treec7b44c9c0c4fb39fbba08f97323570131146e215 /src/compiler/scala/tools/ant/Scaladoc.scala
parentfef68d7c3f75d5a5e5a0f05b8fcb60ede227a437 (diff)
downloadscala-2647716232805f77ed81eabc491759f5362d5e01.tar.gz
scala-2647716232805f77ed81eabc491759f5362d5e01.tar.bz2
scala-2647716232805f77ed81eabc491759f5362d5e01.zip
added scaladoc options and dependency check
Diffstat (limited to 'src/compiler/scala/tools/ant/Scaladoc.scala')
-rw-r--r--src/compiler/scala/tools/ant/Scaladoc.scala24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/compiler/scala/tools/ant/Scaladoc.scala b/src/compiler/scala/tools/ant/Scaladoc.scala
index fd8cfc61d0..33ba2f1ded 100644
--- a/src/compiler/scala/tools/ant/Scaladoc.scala
+++ b/src/compiler/scala/tools/ant/Scaladoc.scala
@@ -41,7 +41,7 @@ import scala.tools.nsc.reporters.{Reporter, ConsoleReporter}
* <li>extdirsref,</li>
* <li>encoding,</li>
* <li>windowtitle,</li>
- * <li>documenttitle,</li>
+ * <li>doctitle,</li>
* <li>addparams,</li>
* <li>deprecation,</li>
* <li>unchecked.</li>
@@ -101,7 +101,7 @@ class Scaladoc extends MatchingTask {
/** The window title of the generated HTML documentation. */
private var windowtitle: Option[String] = None
/** The document title of the generated HTML documentation. */
- private var documenttitle: Option[String] = None
+ private var doctitle: Option[String] = None
/** Instruct the compiler to use additional parameters */
private var addParams: String = ""
@@ -257,12 +257,12 @@ class Scaladoc extends MatchingTask {
def setWindowtitle(input: String): Unit =
windowtitle = Some(input)
/** Sets the <code>documenttitle</code> attribute.
*
* @param input The value of <code>documenttitle</code>.
*/
- def setDocumenttitle(input: String): Unit =
- documenttitle = Some(input)
+ def setDoctitle(input: String): Unit =
+ doctitle = Some(input)
/** Set the <code>addparams</code> info attribute.
*
@@ -476,14 +476,14 @@ class Scaladoc extends MatchingTask {
if (!extdirs.isEmpty) settings.extdirs.value = asString(getExtdirs)
if (!encoding.isEmpty) settings.encoding.value = encoding.get
if (!windowtitle.isEmpty) settings.windowtitle.value = windowtitle.get
- if (!documenttitle.isEmpty) settings.documenttitle.value =
+ if (!doctitle.isEmpty) settings.doctitle.value =
// In Ant script characters '<' and '>' must be encoded when
// used in attribute values, e.g. for attribute "documenttitle"
// in task Scaladoc you may write:
- // documenttitle="&lt;div&gt;Scala&lt;/div&gt;"
+ // doctitle="&lt;div&gt;Scala&lt;/div&gt;"
// so we have to decode them here.
- documenttitle.get.replaceAll("&lt;", "<").replaceAll("&gt;",">")
- .replaceAll("&amp;", "&").replaceAll("&quot;", "\"")
+ doctitle.get.replaceAll("&lt;", "<").replaceAll("&gt;",">")
+ .replaceAll("&amp;", "&").replaceAll("&quot;", "\"")
settings.deprecation.value = deprecation
settings.unchecked.value = unchecked
log("Scaladoc params = '" + addParams + "'", Project.MSG_DEBUG)
@@ -516,7 +516,7 @@ class Scaladoc extends MatchingTask {
val global: compiler.type = compiler
def outdir = settings.outdir.value
def windowTitle = settings.windowtitle.value
- def documentTitle = settings.documenttitle.value
+ def docTitle = settings.doctitle.value
}
generator.process(run.units)
if (reporter.ERROR.count > 0)
@@ -257,12 +257,12 @@ class Scaladoc extends MatchingTask {
def setWindowtitle(input: String): Unit =
windowtitle = Some(input)
- /** Sets the <code>documenttitle</code> attribute.
+ /** Sets the <code>doctitle</code> attribute.
*
@@ -257,12 +257,12 @@ class Scaladoc extends MatchingTask {
*
- * @param input The value of <code>documenttitle</code>.
+ * @param input The value of <code>doctitle</code>.
*/
@@ -476,14 +476,14 @@ class Scaladoc extends MatchingTask {
// In Ant script characters '<' and '>' must be encoded when
- // used in attribute values, e.g. for attribute "documenttitle"
+ // used in attribute values, e.g. for attribute "doctitle"
// in task Scaladoc you may write: